@@ -87,15 +87,17 @@
       userspace and make it dependent on the user to activate the logging. 
       Definitely, an intruder does not start e.g. <tt>/usr/bin/script</tt>
       voluntarily. I have only seen few other kernel-based loggers. One of them
-      is sadly outdated, others query the X86 keyboard driver (very unportable,
-      and does not work with exotic keyboards, not to mention network traffic)
-      instead of tty lines, and some only allow ghost-network transfer. To sum
-      it up, there exist only very few solutions to which I could compare.</p>
+      is sadly outdated, others query the X86 keyboard driver using interrupt
+      hijacking and table translation. This is very unportable, because it only
+      catches AT keyboards, but not USB or even other keyboards (unless they
+      are in compatibility mode), and it does not work at all for network
+      traffic. To sum it up, there exist only very few solutions to which I
+      could compare.</p>
 
       <p class="block">Only the FreeBSD snooper <i>watch</i>, which operates on
       the <tt>/dev/snp*</tt> devices, can be taken for a comparison. However,
       it can only do the interactive live feed mode, no logging is possible for
-      later replay, line and time stamps are missing.</p>
+      later replay. Packet time stamps are also missing.</p>
 
     </td>
   </tr>
