@@ -42,10 +42,11 @@ freebsd-5.3/rpldev.c - Kernel interface for RPLD
 #include "../include/rpl_packet.h"
 
 #define IO_NDELAY      0x10 // from sys/vnode.h -- inclusion problems
-#define SKIP_PTM(tty)  if(umajor(dev2udev(tty->t_dev)) == 6) return 0;
+#define SKIP_PTM(tty)  // not needed in FreeBSD
 #define TTY_DEVNR(tty) htole32(mkdev_26(umajor(dev2udev(tty->t_dev)), \
                        uminor(dev2udev(tty->t_dev))))
 #define RET_IF_INACT   if(!kmi_usecount) return 0;
+#define RET_IF_NULLTTY if(tty == NULL) return 0;
 
 // Module stuff
 static int kmd_event(module_t, int, void *);
@@ -139,6 +140,7 @@ static int krpl_init(struct cdev *cd, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
 
     p.dev   = TTY_DEVNR(tty);
@@ -153,6 +155,7 @@ static int krpl_open(struct cdev *cd, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
 
     p.dev   = TTY_DEVNR(tty);
@@ -167,6 +170,7 @@ static int krpl_read(const char *buf, int count, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
     if(count == 0) return 0;
 
@@ -182,6 +186,7 @@ static int krpl_write(const char *buf, int count, struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
     if(count == 0) return 0;
 
@@ -199,6 +204,7 @@ static int krpl_ioctl(struct tty *tty, u_long cmd, void *arg) {
     uint32_t cmd32;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
 
     cmd32   = cmd;
@@ -215,6 +221,7 @@ static int krpl_close(struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
 
     p.dev   = TTY_DEVNR(tty);
@@ -229,6 +236,7 @@ static int krpl_deinit(struct tty *tty) {
     struct rpldev_packet p;
 
     RET_IF_INACT;
+    RET_IF_NULLTTY;
     SKIP_PTM(tty);
 
     p.dev   = TTY_DEVNR(tty);
@@ -296,8 +304,8 @@ static int urpl_read(struct cdev *cd, struct uio *uio, int flags) {
 static int urpl_ioctl(struct cdev *cd, u_long cmd, caddr_t data, int flags,
  struct thread *th)
 {
-    /* Gah, it does not even support multiple return values >:-( so I need to
-    hack around with data. */
+    /* Stupid BSD, it does not even support multiple return values >:-(
+    so I need to hack around with data. */
     size_t *ptr = (void *)data;
     if(IOCGROUP(cmd) != RPL_IOC_MAGIC)
         return ENOTTY;
