@@ -28,10 +28,10 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include "rpl_stdint.h"
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20051112
+#if !defined(_LIBHX_H) || _LIBHX_H < 20051203
 #    error ----------------------------------------
 #    error You need a newer version of libHX
-#    error (at least 1.7.1 / 0_7-20051112)
+#    error (at least 1.7.3)
 #    error http:/jengelh.hopto.org/coding/libHX.php
 #    error ----------------------------------------
 #endif
