@@ -145,7 +145,7 @@ module_param(Minor_nr, int, S_IRUGO);
 #endif
 
 //-----------------------------------------------------------------------------
-__init extern int init_module(void) {
+__init static int rpldev_init(void) {
     int eax;
     kmi_miscinfo.minor = Minor_nr;
     if((eax = misc_register(&kmi_miscinfo)) != 0)
@@ -155,11 +155,14 @@ __init extern int init_module(void) {
     return 0;
 }
 
-__exit extern void cleanup_module(void) {
+__exit static void rpldev_exit(void) {
     misc_deregister(&kmi_miscinfo);
     return;
 }
 
+module_init(rpldev_init);
+module_exit(rpldev_exit);
+
 //-----------------------------------------------------------------------------
 static int krpl_init(struct tty_struct *tty, struct tty_struct *ctl,
  struct file *filp)
