@@ -143,6 +143,16 @@ clthr__exit:
 }
 
 //-----------------------------------------------------------------------------
+#ifdef __linux__
+#    define ARCH "Linux"
+#elif defined(__FreeBSD__)
+#    define ARCH "FreeBSD"
+#elif defined(__OpenBSD__)
+#    define ARCH "OpenBSD"
+#else
+#    define ARCH "Other"
+#endif
+
 static void getinfo_text(uint32_t dev, int fd) {
     pthread_mutex_lock(&Ttys_lock);
     if(dev == 0) {
@@ -153,7 +163,7 @@ static void getinfo_text(uint32_t dev, int fd) {
         skprintf(fd,
           "=========================================================="
           "================\n"
-          "  *           %9llu %9llu ttyrpld " TTYRPLD_VERSION "\n"
+          "  *           %9llu %9llu ttyrpld " TTYRPLD_VERSION "/" ARCH "\n"
           "  IOCD: %lu/%lu/%lu/%lu  RW: %lu/%lu  I: %lu  B: %lu\n"
           "----------------------------------------------------------"
           "----------------\n",
