@@ -90,7 +90,7 @@ static void *pctrl_thread(void *arg) {
         read(ctty, &c, 1);
         switch(tolower(c)) {
             case ' ':
-                pstatus->paused ^= -1;
+                pstatus->paused ^= (unsigned long)-1;
                 break;
             case '<':
                 pstatus->brk = PCTRL_PREV;
@@ -98,11 +98,17 @@ static void *pctrl_thread(void *arg) {
             case '>':
                 pstatus->brk = PCTRL_NEXT;
                 break;
+            case '[':
+                pstatus->factor -= 1.10;
+                break;
+            case ']':
+                pstatus->factor += 1.10;
+                break;
             case 'c':
-                pstatus->factor *= 1.33;
+                pstatus->factor *= 1.0 + 1.0 / 3.0;
                 break;
             case 'e':
-                pstatus->echo ^= -1;
+                pstatus->echo ^= (unsigned long)-1;
                 break;
             case '6':
                 if(pstatus->skval < 0)
