@@ -63,8 +63,10 @@ struct tty *get_tty(uint32_t dev, int create) {
     struct HXbtree_node *ts;
     struct tty *ret = NULL, *tty;
 
-    if((ret = HXbtree_get(Ttys, (void *)dev)) != NULL) { return ret; }
-    if(!create || (tty = malloc(sizeof(struct tty))) == NULL) { return NULL; }
+    if((ret = HXbtree_get(Ttys, (void *)dev)) != NULL)
+        return ret;
+    if(!create || (tty = malloc(sizeof(struct tty))) == NULL)
+        return NULL;
 
     tty->dev      = dev;
     tty->uid      = -1;
@@ -142,7 +144,8 @@ ssize_t send_wait(int fd, const void *buf, size_t count, int flags) {
 //-----------------------------------------------------------------------------
 static inline long K_VERSION(void) {
     pthread_mutex_lock(&k_version_lock);
-    if(k_version_data == 0) { setup_kversion(); }
+    if(k_version_data == 0)
+        setup_kversion();
     pthread_mutex_unlock(&k_version_lock);
     return k_version_data;
 }
@@ -150,8 +153,10 @@ static inline long K_VERSION(void) {
 static void setup_kversion(void) {
     int x, y, z;
     FILE *fp;
-    if((fp = fopen("/proc/version", "r")) == NULL) { return; }
-    if(fscanf(fp, "%*s %*s %d.%d.%d", &x, &y, &z) != 3) { return; }
+    if((fp = fopen("/proc/version", "r")) == NULL)
+        return;
+    if(fscanf(fp, "%*s %*s %d.%d.%d", &x, &y, &z) != 3)
+        return;
     fclose(fp);
     k_version_data = KERNEL_VERSION(x, y, z);
     return;
