@@ -94,7 +94,6 @@ static struct {
     int _running, dolog;
     char *device;
     long bsize;
-
     int infod_start;
 } Opt = {
     ._running    = 1,
@@ -138,6 +137,7 @@ int main(int argc, const char **argv) {
           " conditions; for\n" "details see the \"LICENSE\" file which should"
           " have come with this program.\n")
         );
+        printf("\n");
     }
 
     if((Ttys = HXbtree_init(HXBT_MAP | HXBT_ICMP)) == NULL) {
@@ -473,7 +473,8 @@ static void fill_info(struct tty *tty, const char *aux_sdev) {
             }
             ++dirp;
         }
-        if(pbase == NULL && *full_dev == '/') { pbase = ""; }
+        if(pbase == NULL && *full_dev == '/')
+            pbase = "";
     } else if(!find_devnode(tty->dev, full_dev, sizeof(full_dev), &pbase)) {
         /* Use [MAJOR:MINOR] as a fictitious filename if the device node
         could not be found. */
@@ -548,14 +549,18 @@ static int init_device(const char *in_devs) {
                 printf(_("Connected to %s\n"), devp);
             break;
         }
-        if(errno != ENOENT)
+        if(errno != ENOENT) {
+            if(errno == EACCES)
+                fprintf(stderr, _("The device should be owned by the user "
+                 "running rpld (uid %ld) and have mode 0400.\n"), GOpt.user_id);
             fprintf(stderr, _("static_find(): Could not open %s even"
              " though it exists: %s (trying next device)\n"),
              devp, strerror(errno));
-        else if(errno == EBUSY)
+        } else if(errno == EBUSY) {
             fprintf(stderr, _("\t" "The RPL device can only be opened"
              " once,\n\t" "there is probably an instance of rpld"
              " running!\n"));
+        }
     }
 
     free(copy);
